#
# spec file for package podlet
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           podlet
Version:        0.3.0~0
Release:        1.4
Summary:        Podman quadlet generator
License:        MPL-2.0
URL:            https://github.com/containers/podlet/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging

%description
Podlet generates podman quadlet files from a podman command, compose file, or existing object.

%prep
%autosetup -p1 -a1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/podlet

%changelog
* Mon Sep 23 2024 opensuse_buildservice@ojkastl.de
- update to version 0.3.0~0:
  Big release for Podlet!
  In case you didn't already notice, Podlet is now officially a
  part of the Containers community! As a part of the transition, a
  new code of conduct, security policy, and contribution guidelines
  were added (#76). Additionally, the Podlet container image is now
  available at ghcr.io/containers/podlet. The existing images at
  quay.io/k9withabone/podlet and docker.io/k9withabone/podlet are
  deprecated and will not be receiving updates.
  Under the hood, the library used to deserialize Compose files was
  changed (#73). As a result, only Compose files which follow the
  Compose specification are supported. The top-level version field
  is completely ignored. Most Compose files should still work as
  before.  This was a large change so look out for bugs.
  Added support for Quadlet options introduced in Podman v5.0.0
  (#75). The headline feature is support for generating Quadlet
  .pod files. They can be generated from:
  * A Podman command with podlet podman pod create.
  * A Compose file with podlet compose --pod.
  * An existing pod with podlet generate pod.
  - This creates a .pod file and a .container file for each
    container in the pod.
  Note that the existing option for generating Kubernetes Pod YAML
  from a Compose file was renamed to podlet compose --kube. Both
  the --pod and --kube options of podlet compose do not take an
  argument and instead require the top-level name field in the
  Compose file. The name is used as the name of the pod and in the
  filename of the created files.
  * Features
  - Add podlet --binds-to option.
  - BREAKING (compose) Rename podlet compose --pod to podlet
    compose --kube.
  - (container) Add Entrypoint= Quadlet option.
  - (container) Add StopTimeout= Quadlet option.
  - (container) Support Notify=healthy Quadlet option.
  - (container) Support no-dereference option for Mount=.
  - (container) Add podman run --preserve-fd option.
  - (container) Add podman run --gpus option.
  - (container) Add podman run --retry option.
  - (container) Add podman run --retry-delay option.
  - Add podman --config global option.
  - (pod) Generate .pod Quadlet file from command.
  - Adds the podlet podman pod create subcommand.
  - The --infra-conmon-pidfile and --pod-id-file options were
    deliberately not implemented as they are set by Quadlet in
    the generated {name}-pod.service file and can't be set
    multiple times.
  - BREAKING (compose) Re-add podlet compose --pod option.
  - The --pod option causes podlet to create a .pod Quadlet
    file in addition to the .container, .volume, and .network
    files. The containers are linked to the pod and their
    published ports are moved.
  - (generate) Quadlet files from an existing pod and its
    containers.
  - Adds the podlet generate pod subcommand.
  - Runs podman pod inspect on the given pod.
  - Deserializes the output.
  - Parses the pod creation command.
  - Does the same for each of the pod's containers.
  * Bug Fixes
  - Use Quadlet serializer for Unit Display implementation (#64).
  - Brings Unit inline with the other sections of the generated
    Quadlet file.
  - (container) Add podman run --uts option.
  - (container) --pids-limit range is -1..=u32::MAX.
  - (container) Enforce --blkio-weight range 10..=1000.
  - (container) --blkio-weight-device can be specified multiple
    times.
  - (container) Don't add empty PodmanArgs= when downgrading
    Podman version.
  - Correct use of eyre::bail!() on non-Unix platforms.
  * Documentation
  - (clippy) Fix Clippy lint warning for Idmap.
  - (compose) --kube help add name requirement.
  - Add code of conduct.
  - Add security policy.
  - Update links to the repository.
  - The repository is now at
    https://github.com/containers/podlet.
  - (contributing) Add contribution guidelines.
  - Adapted from the Buildah/Podman contribution guidelines.
  - Suggests the use of conventional commits and clarifies that
    the Signed-off-by footer is required for a PR to be merged.
  - Moved and expanded upon the building and continuous
    integration sections from the README.md file to the new
    CONTRIBUTING.md file.
  - (readme) Update container image location.
  - The Podlet container image is now located at
    ghcr.io/containers/podlet.
  - Fix Podman and Quadlet capitalization.
  - (readme) Update demo, features, and usage.
  * Refactor
  - BREAKING (deps) Remove docker_compose_types.
  - BREAKING (compose) Deserialize compose_spec::Compose.
  - cli::Unit::is_empty()
  - Check each field instead of comparing to the default.
  - (compose) Conversion to quadlet::Files from
    compose_spec::Compose.
  - (compose) quadlet::Globals from compose_spec::Service.
  - (compose) Container Quadlet options from
    compose_spec::Service.
  - (compose) Container Podman args from compose_spec::Service.
  - (compose) quadlet::Network from compose_spec::Network.
  - (compose) quadlet::Volume from compose_spec::Volume.
  - (compose) Kubernetes YAML from compose_spec::Compose.
  - (container) Destructure in Quadlet option conversion.
  - (compose) Move podlet compose args into their own struct.
  * Miscellaneous
  - (deps) Remove duration-str dependency.
    . All usages were replaced with compose_spec::duration.
  - Add Podman v5.0.0 to Podman versions.
  - Also added v4.9.X aliases to 4.8 and v5.0.X aliases to 5.0.
  - (container) Reorder fields to match Quadlet docs.
  - (lints) Fix new rust 1.78 clippy lints.
  - BREAKING (release-container) Push to
    ghcr.io/containers/podlet.
  - The docker.io/k9withabone/podlet and
    quay.io/k9withabone/podlet container images will no longer
    be updated.
  - (release-container) Add annotations/labels to manifest/image.
  - Adds labels to the Podlet container image and annotations
    to the multi-arch manifest as suggested by the GitHub
    packages documentation:
    https://docs.github.com/en/packages/working-with-a-github-packages-registry/working-with-the-container-registry#labelling-container-images.
  - (ci) Bump actions/checkout to v4.
  - (ci) Use Buildah container to build Podlet container.
  - (deps) Update dependencies.
  - (release) Update cargo-dist.
  - (release-container) Fix manifest annotation quoting.
  - (ci) Use consistent formatting.
  - (ci) Add image to manifest when building container.
  - (ci) Add build job.
* Tue Jun  4 2024 Frederic Crozat <fcrozat@suse.com>
- Drop source url, since tarball is generated with source service.
* Tue May 14 2024 Frederic Crozat <fcrozat@suse.com>
- Only package .obscpio and adapt _service accordingly.
* Fri Mar 29 2024 fcrozat@suse.com
- Initial package, version 0.2.4~0:
  * release: podlet v0.2.4
  * ci: update cargo-dist
  * chore: update dependencies
  * docs(readme): update demo, features, and usage
  * fix(generate): correct help message
  * chore: add podman v4.9.0 to podman versions
  * feat: absolute host paths option
  * refactor: downgrade as a trait
- Warning, vendor tarball forced to lock to docker-compose-types
  v0.7.1, until upstream switches to semver.
* Fri Mar 22 2024 Frederic Crozat <fcrozat@suse.com>
- Initial package
